/* -*- mode: C; c-file-style: "stroustrup"; indent-tabs-mode: nil; -*-*/
/*
 *
 * Definitions of Application Switcher
 *   
 */


/*
 * This file is part of hildon-navigator
 *
 * Copyright (C) 2005 Nokia Corporation.
 *
 * Contact: Karoliina Salminen <karoliina.t.salminen@nokia.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef APPLICATION_SWITCHER_H
#define APPLICATION_SWITCHER_H

#include <gtk/gtkbutton.h>

/* Hardcoded list position for the four recently opened window items */
#define ITEM_1_LIST_POS 2                          
#define ITEM_2_LIST_POS 3
#define ITEM_3_LIST_POS 4                             
#define ITEM_4_LIST_POS 5

/* Menu item strings */
#define STRING_HOME _("tana_fi_home")
#define STRING_INSENSITIVE_INFOPRINT _("tana_ib_please_close_dialog") 

/* Defined workarea atom */
#define WORKAREA_ATOM "_NET_WORKAREA"

/* Icon name of the Application switcher menu button */
#define AS_SWITCHER_BUTTON_ICON "qgn_list_tasknavigator_appswitcher" 

/* Icon name for the 'default' icon */
#define MENU_ITEM_DEFAULT_APP_ICON    "qgn_list_gene_default_app"

/* Icon name for the Home AS menu item icon */

#define HOME_MENU_ITEM_ICON "qgn_list_home"

/* Themed widget names */
#define SMALL_BUTTON1_NORMAL "hildon-navigator-small-button1"
#define SMALL_BUTTON2_NORMAL "hildon-navigator-small-button2"
#define SMALL_BUTTON3_NORMAL "hildon-navigator-small-button3"
#define SMALL_BUTTON4_NORMAL "hildon-navigator-small-button4"

#define SMALL_BUTTON1_PRESSED "hildon-navigator-small-button1-pressed"
#define SMALL_BUTTON2_PRESSED "hildon-navigator-small-button2-pressed"
#define SMALL_BUTTON3_PRESSED "hildon-navigator-small-button3-pressed"
#define SMALL_BUTTON4_PRESSED "hildon-navigator-small-button4-pressed"

#define NAME_SMAL_MENU_BUTTON_ITEM "hildon-navigator-small-button5"

#define NAME_UPPER_SEPARATOR "hildon-navigator-upper-separator"
#define NAME_LOWER_SEPARATOR "hildon-navigator-lower-separator"

/* Definitions for the application switcher menu position changes */

#define AS_MENUITEM_SAME_POSITION 0
#define AS_MENUITEM_TO_FIRST_POSITION 1
#define AS_MENUITEM_TO_LAST_POSITION 2

typedef  struct ApplicationSwitcher ApplicationSwitcher_t;

/* application_switcher_init
 * Called to initialise the application switcher. This function 
 * creates widgets to the lowest task navigator area. Area includes four 
 * small icon buttons and application switcher menu button which are 
 * packed into a vbox.
 * 
 * @returns ApplicationSwitcher_t : pointer to a new ApplicationSwitcher.
 */
ApplicationSwitcher_t *application_switcher_init( void );

/* application_switcher_get_button
 * Called to return the lowest button area widget.
 *  
 * @param ApplicationSwitcher_t Returned by a previous call to
 *                              application_switcher_init()
 */
GtkWidget *application_switcher_get_button(ApplicationSwitcher_t *as);

/* application_switcher_initialize_menu
 * Called to initialise the application switcher menu and tooltip menu.
 * Function also sets the callbacks for widgets and creates an array to 
 * store information of open windows. Menu gets their information of 
 * added/updated/removed windows from window manager. 
 *  
 * @param ApplicationSwitcher_t Returned by a previous call to
 *                              application_switcher_init()
 */
void application_switcher_initialize_menu(ApplicationSwitcher_t *as);

/* application_switcher_get_killable_item
 * Called to return the first killable item from list of the open 
 * windows.
 *  
 * @param ApplicationSwitcher_t Returned by a previous call to
 *                              application_switcher_init()
 *
 * @returns the item of the killable window in the list, or NULL if
 * the list has no open windows.
 */
GtkWidget *application_switcher_get_killable_item(
                                              ApplicationSwitcher_t *as);

/* application_switcher_deinit
 * Used to clean up the structure just before it gets unloaded.
 *  
 * @param ApplicationSwitcher_t Returned by a previous call to
 *                              application_switcher_init()
 */
void application_switcher_deinit(ApplicationSwitcher_t *as);


/* application_switcher_get_menuitems
 * Used to get the list of AS menuitem pointers for session saving
 *
 * @param ApplicationSwitcher_t The structure containing the
 *                              Application Switcher information
 */

GList *application_switcher_get_menuitems(ApplicationSwitcher_t *as);


void *application_switcher_get_dnotify_handler(ApplicationSwitcher_t *as);

void application_switcher_set_dnotify_handler(ApplicationSwitcher_t *as, 
                                              gpointer update_cb_ptr);

#endif /* APPLICATION_SWITCHER_H */
